@@ -28,6 +28,7 @@ class DBVendor(str, Enum):
 
 class TLSSecurity(str, Enum):
     insecure = "insecure"
+    default = "default"
 
 
 class PropertyConfig(BaseModel):
@@ -360,6 +361,7 @@ def build_node_and_resolver(
     edge_resolver_map_strs: T.List[str],
     hydrate: bool,
     dehydrate: bool,
+    allow_inserting_id: bool = True,
 ) -> str:
     # need to sort props and links by required, exclusive, no default, rest
     object_type.properties.sort(
@@ -455,7 +457,7 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
     self.{property_name} = {prop.name}
                     """
                 )
-        if prop.name != "id":
+        if prop.name != "id" or allow_inserting_id:
             # for insert type
             if not prop.is_computed and not prop.not_insertable:
                 insert_edgedb_conversion_map[prop.name] = {
@@ -466,9 +468,17 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
                 insert_type_str = type_str
                 # if required but has default, add optional back
                 if prop.required and prop.default:
-                    insert_type_str = f"T.Optional[{insert_type_str}]"
+                    # insert_type_str = f"T.Optional[{insert_type_str}]"
+                    insert_type_str = f"T.Union[{insert_type_str}, UnsetType]"
+                if insert_type_str.startswith("T.Optional["):
+                    insert_type_str_test = (
+                        "T.Union[" + insert_type_str[11:-1] + ", None, UnsetType]"
+                    )
+                    insert_type_str = insert_type_str_test
                 default_value_str = (
-                    " = None" if insert_type_str.startswith("T.Optional[") else ""
+                    " = Field(default_factory=UnsetType)"
+                    if insert_type_str.endswith("UnsetType]")
+                    else ""
                 )
                 insert_property_strs.append(
                     f"{prop.name}: {insert_type_str}{default_value_str}"
