@@ -40,9 +40,9 @@ class NestedResolvers(BaseModel):
             new_resolvers: list["Resolver"] = []
             has_merged = False
             for existing_r in existing_resolvers:
-                if (
+                if has_merged is False and (
                     merged_r := merge_resolvers(resolver, existing_r)
-                ) and has_merged is False:
+                ):
                     new_resolvers.append(merged_r)
                     has_merged = True
                 else:
